@@ -1,6 +1,6 @@
 
 # -*- encoding: utf-8 -*-
-# Copyright (c) 2014 - Dedsert Ltd.
+# Copyright (c) 2014.
 
 """
 .. module:: DoBy
@@ -11,8 +11,8 @@
 .. modelauthor:: Adam Drakeford <adamdrakeford@gmail.com>
 """
 
-from datetime import datetime
 from dateutil import parser
+from datetime import datetime
 
 
 class DoBy(Exception):
@@ -30,6 +30,9 @@ class DoBy(Exception):
 
 def TODO(note, doby):
     """ Call me to raise an exception if a TODOs
-        is not done by a certain time
+        is not done by a certain time.
+        :param note: a str for the TODO note.
+        :param doby: a str or datetime object for the date
+            in which the TODO is to be done by.
     """
     DoBy(note, doby)
